%photoelectric_effect

function photoelectric_effect

%% Inputs %%

%Planck's constant /m^2kgs^-1
h = 6.626068e-34;

%Charge on the electron /coulombs
qe = 1.602176620898e-19;

%Speed of light /ms^-1
c = 299792458;

%Choose radiation wavelength /nm
%http://science-edu.larc.nasa.gov/EDDOCS/Wavelengths_for_Colors.html
lambda_violet = 400;  %Violet
lambda_indigo = 445;  %Indigo
lambda_blue = 475;  %Blue
lambda_green = 510;  %Green
lambda_yellow = 570;  %Yellow
lambda_orange = 590;  %Orange
lambda_red = 650;  %Red

%Convert wavelengths to frequency /Hz
f_violet = c/(lambda_violet*1e-9);
f_indigo = c/(lambda_indigo*1e-9);
f_blue = c/(lambda_blue*1e-9);
f_green = c/(lambda_green*1e-9);
f_yellow = c/(lambda_yellow*1e-9);
f_orange = c/(lambda_orange*1e-9);
f_red = c/(lambda_red*1e-9);

%Work function of metals /eV
W = 4.3;  %Silver
W = 4.3;  %Aluminium
W = 5.1;  %Gold
W = 4.7;  %Copper
W = 4.4;  %Tin
W = 4.3;  %Lead
W = 4.5;  %Tungsten
W = 4.6;  %Nickel
W = 2.4;  %Sodium

W = 4.7;

%Convert to J
W = W*qe;

%Fontsize for graphs
fsize = 18;

%Number of data points for graphs
N = 1000;

%

%% Photoelectric effect model %%

%Calculate cutoff frequency /Hz
f_cutoff = W/h;

%Define range of frequencies
f = linspace( 0, f_cutoff*2, N );

%Define stopping voltages associated with electrons emmitted
%due to photons of frequency f
V = h*f/qe - W/qe;
V(V<0) = NaN;

%Generate extrapolated stopping potential
V_extrap = h*f/qe - W/qe;

%

%% Plot graph of stopping voltage vs frequency
figure('color',[1 1 1],'name','photoelectric effect')
plot(f,V,'m-','linewidth',1);
hold on;
plot(f,V_extrap,'m--','linewidth',1);
ylimits = get(gca,'ylim');
set(gca,'ytick',floor(ylimits(1)):ceil(ylimits(2)));
plot( [f_red,f_red],ylimits,'r-');
plot( [f_yellow,f_yellow],ylimits,'y-');
plot( [f_green,f_green],ylimits,'g-');
plot( [f_blue,f_blue],ylimits,'b-');
plot( [f_cutoff,f_cutoff],ylimits,'m--');
axis tight;
xlabel('Frequency /Hz','fontsize',fsize);
ylabel('Stopping voltage /volts','fontsize',fsize);
title(['Photoelectric effect: W = ',num2str(W/qe),'eV'],'fontsize',fsize)
set(gca,'fontsize',fsize);
grid on;
print(gcf,'photoelectric effect.png','-dpng','-r300');
close(gcf);

%End of code